==> appfs-21.02.tar.gz: usr/local/www/berogui/includes/variables.php <==
<?php
$appversion='';
$version=@file("./VERSION");
if ($version!=NULL){
foreach ($version as $key => $line){
$v=  explode("=",$line);
#$appversion="v.".$v[1];
$appversion="";
}
}
define ("show","no");
define ("APPVERSION", $appversion);
define ("db_path", "/usr/conf/ari.db");
define ("db_path_isdn", "/usr/conf/app.db");
//Parameter für [intern] in create_file beroextensions.conf
define ("parameter_1", "20");
define ("parameter_2", "t");

// define serial
// TODO: should be avoided to load n-times this file. as beronode, it should be only one time
if (@file_exists('/etc/beroNet/sbc.conf')) {
	$sbc_conf = parse_ini_file('/etc/beroNet/sbc.conf');
	define("SERIAL", $sbc_conf['SBCVM_SERIAL']);
}
else {
	define("SERIAL", trim(file_get_contents('/sys/class/beronet/gateway/serial')));
}

$isdn_causes=array(array(0=>"0: &lt;No cause&gt;"),
array(1=>"1: Unallocated number"),
array(2=>"2: No route to transit network"),
array(3=>"3: No route to destination"),
array(4=>"4: &lt;Listen to announcement...&gt;"),
array(5=>"5: Misdialed trunk prefix."),
array(6=>"6: Channel unacceptable"),
array(8=>"8: Preemption"),
array(9=>"9: Preemption - circuit reserved"),
array(16=>"16: Normal call clearing"),
array(17=>"17: User busy"),
array(18=>"18: No user responding"),
array(19=>"19: No answer from user"),
array(20=>"20: Subscriber absent"),
array(21=>"21: Call rejected"),
array(22=>"22: Number changed"),
array(26=>"26: Non-selected user clearing"),
array(27=>"27: Destination out of order"),
array(28=>"28: Invalid number (incomplete)"),
array(29=>"29: Facility rejected"),
array(31=>"31: Normal, unspecified"),
array(34=>"34: No circuit/channel available"),
array(41=>"41: Temporary failure"),
array(42=>"42: Switchting equipment congestion"),
array(43=>"43: Access informationen discarded"),
array(44=>"44: No requested circuit/channel"),
array(46=>"46: Precedence call blocked"),
array(47=>"47: Resource unavailable, unspecified"),
array(49=>"49: Quality of service not available"),
array(50=>"50: Requested facility not subscribed"),
array(53=>"53: Outgoing calls barred within CUG"),
array(55=>"55: Incoming calls barred within CUG"),
array(57=>"57: Bearer capability not authorized"),
array(58=>"58: Bearer capability not present"),
array(63=>"63: Service or option not available"),
array(65=>"65: Bearer capability not implement."),
array(66=>"66: Channel type not implemented"),
array(69=>"69: Requested facility not implement."),
array(70=>"70: restricted digital informat. only"),
array(79=>"79: Service or option not implemented"),
array(81=>"81: Invalid call reference value"),
array(82=>"82: Identified channel does not exist"),
array(83=>"83: No suspended call with this id"),
array(84=>"84: Call identity in use"),
array(85=>"85: No call suspended"),
array(86=>"86: Suspended call has been cleared"),
array(87=>"87: User not member of CUG"),
array(88=>"88: Incompatibel destination"),
array(90=>"90: Non-existent CUG"),
array(91=>"91: Invalid transit network selection"),
array(95=>"95: Invalid message, unspecified"),
array(96=>"96: Information element missing"),
array(97=>"97: Message type non-existent"),
array(98=>"98: Message not compatible with state"),
array(99=>"99: Information element not impl."),
array(100=>"100: Invalid info element contents"),
array(101=>"101: Message not compatible with state"),
array(102=>"102: Recovery on timer expiry"),
array(103=>"103: Parameter non-existent"),
array(111=>"111: Protocol error, unspecified"),
array(127=>"127: Interworking, unspecified"));

$sip_response=array(array(300=>"300 Multiple Choices"),
array(301=>"301 Moved Permanently"),
array(302=>"302 Moved Temporarily"),
array(305=>"305 Use Proxy"),
array(380=>"380 Alternative Service"),
array(400=>"400 Bad Request"),
array(401=>"401 Unauthorized"),
array(402=>"402 Payment Required (Reserved for future use)"),
array(403=>"403 Forbidden"),
array(404=>"404 Not Found"),
array(405=>"405 Method Not Allowed"),
array(406=>"406 Not Acceptable"),
array(407=>"407 Proxy Authentication Required"),
array(408=>"408 Request Timeout"),
array(409=>"409 Conflict"),
array(410=>"410 Gone"),
array(413=>"413 Request Entity Too Large"),
array(414=>"414 Request-URI Too Long"),
array(415=>"415 Unsupported Media Type"),
array(416=>"416 Unsupported URI Scheme"),
array(420=>"420 Bad Extension"),
array(421=>"421 Extension Required"),
array(422=>"422 Session Interval Too Small"),
array(423=>"423 Interval Too Brief"),
array(480=>"480 Temporarily Unavailable"),
array(481=>"481 Call/Transaction Does Not Exist"),
array(482=>"482 Loop Detected"),
array(483=>"483 Too Many Hops"),
array(484=>"484 Address Incomplete"),
array(485=>"485 Ambiguous"),
array(486=>"486 Busy Here"),
array(487=>"487 Request Terminated"),
array(488=>"488 Not Acceptable Here"),
array(491=>"491 Request Pending"),
array(493=>"493 Undecipherable"),
array(500=>"500 Server Internal Error"),
array(501=>"501 Not Implemented"),
array(502=>"502 Bad Gateway"),
array(503=>"503 Service Unavailable"),
array(504=>"504 Server Time-out"),
array(505=>"505 Version Not Supported"),
array(513=>"513 Message Too Large"),
array(600=>"600 Busy Everywhere"),
array(603=>"603 Decline"),
array(604=>"604 Does Not Exist Anywhere"),
array(606=>"606 Not Acceptable")
);

$isgw_cause=array(array(901=>"901 means no channel processing resources are left to establish a call"),
array(902=>"902 means no isdn channels are free to establish a call"),
array(903=>"903 means no general resources are free to establish a call"),
array(904=>"904 means no match in isgw dialplan was found"),
array(905=>"905 means the outgoing ISDN Number would contain non-digit characters"),
array(906=>"906 means no ISDN channels are free (ports are down)"),
array(907=>"907 means no ANALOG ports are free"),
array(908=>"908 means no ANALOG channels are free (ports are down)"),
array(909=>"909 means a failover timeout occurred"),
array(910=>"910 means no GSM ports are free"),
array(911=>"911 means no free dialplan entry was found"),
array(912=>"912 means ISDN timeout occurred"),
array(913=>"913 means not enough SIP licenses"),
array(914=>"914 means no CAS ports are free"),
array(915=>"915 means Call blocked by authentication server"),
array(916=>"916 means RTP offer not acceptable"),
array(917=>"917 means T38 offer not acceptable"),
array(918=>"918 means Call limit exceeded"),
array(9000=>"9000 means SIP T0 timeout occurred"),
array(9180=>"9180 means SIP T180 timeout occurred"),
array(9183=>"9183 means SIP T183 timeout occurred"),
array(9200=>"9200 means SIP T200 timeout occurred"),

);

$analog_causes=array(array(17=>"17: User busy"),
array(21=>"21: Call rejected"));
?>

==> appfs-24.01.01.tar.gz: usr/local/www/berogui/includes/variables.php <==
<?php
$appversion='';
$version=@file("./VERSION");
if ($version!=NULL){
foreach ($version as $key => $line){
$v=  explode("=",$line);
#$appversion="v.".$v[1];
$appversion="";
}
}
define ("show","no");
define ("APPVERSION", $appversion);
define ("db_path", "/usr/conf/ari.db");
define ("db_path_isdn", "/usr/conf/app.db");
//Parameter für [intern] in create_file beroextensions.conf
define ("parameter_1", "20");
define ("parameter_2", "t");


// define serial
// TODO: should be avoided to load n-times this file. as beronode, it should be only one time
if (@file_exists('/etc/beroNet/sbc.conf')) {
	$sbc_conf = parse_ini_file('/etc/beroNet/sbc.conf');
	define("SERIAL", $sbc_conf['SBCVM_SERIAL']);
	define ("SIP_USERAGENT_LAN_DEFAULT", 'Cloud SBC v{FIRMWARE}');
	define ("SIP_USERAGENT_WAN_DEFAULT", 'Cloud SBC');
}
else {
	define ("SIP_USERAGENT_LAN_DEFAULT", 'Berofix VoIP Gateway v{FIRMWARE}');
	define ("SIP_USERAGENT_WAN_DEFAULT", 'Berofix VoIP Gateway');
	define("SERIAL", trim(file_get_contents('/sys/class/beronet/gateway/serial')));
}

$isdn_causes=array(array(0=>"0: &lt;No cause&gt;"),
array(1=>"1: Unallocated number"),
array(2=>"2: No route to transit network"),
array(3=>"3: No route to destination"),
array(4=>"4: &lt;Listen to announcement...&gt;"),
array(5=>"5: Misdialed trunk prefix."),
array(6=>"6: Channel unacceptable"),
array(8=>"8: Preemption"),
array(9=>"9: Preemption - circuit reserved"),
array(16=>"16: Normal call clearing"),
array(17=>"17: User busy"),
array(18=>"18: No user responding"),
array(19=>"19: No answer from user"),
array(20=>"20: Subscriber absent"),
array(21=>"21: Call rejected"),
array(22=>"22: Number changed"),
array(26=>"26: Non-selected user clearing"),
array(27=>"27: Destination out of order"),
array(28=>"28: Invalid number (incomplete)"),
array(29=>"29: Facility rejected"),
array(31=>"31: Normal, unspecified"),
array(34=>"34: No circuit/channel available"),
array(41=>"41: Temporary failure"),
array(42=>"42: Switchting equipment congestion"),
array(43=>"43: Access informationen discarded"),
array(44=>"44: No requested circuit/channel"),
array(46=>"46: Precedence call blocked"),
array(47=>"47: Resource unavailable, unspecified"),
array(49=>"49: Quality of service not available"),
array(50=>"50: Requested facility not subscribed"),
array(53=>"53: Outgoing calls barred within CUG"),
array(55=>"55: Incoming calls barred within CUG"),
array(57=>"57: Bearer capability not authorized"),
array(58=>"58: Bearer capability not present"),
array(63=>"63: Service or option not available"),
array(65=>"65: Bearer capability not implement."),
array(66=>"66: Channel type not implemented"),
array(69=>"69: Requested facility not implement."),
array(70=>"70: restricted digital informat. only"),
array(79=>"79: Service or option not implemented"),
array(81=>"81: Invalid call reference value"),
array(82=>"82: Identified channel does not exist"),
array(83=>"83: No suspended call with this id"),
array(84=>"84: Call identity in use"),
array(85=>"85: No call suspended"),
array(86=>"86: Suspended call has been cleared"),
array(87=>"87: User not member of CUG"),
array(88=>"88: Incompatibel destination"),
array(90=>"90: Non-existent CUG"),
array(91=>"91: Invalid transit network selection"),
array(95=>"95: Invalid message, unspecified"),
array(96=>"96: Information element missing"),
array(97=>"97: Message type non-existent"),
array(98=>"98: Message not compatible with state"),
array(99=>"99: Information element not impl."),
array(100=>"100: Invalid info element contents"),
array(101=>"101: Message not compatible with state"),
array(102=>"102: Recovery on timer expiry"),
array(103=>"103: Parameter non-existent"),
array(111=>"111: Protocol error, unspecified"),
array(127=>"127: Interworking, unspecified"));

$sip_response=array(array(300=>"300 Multiple Choices"),
array(301=>"301 Moved Permanently"),
array(302=>"302 Moved Temporarily"),
array(305=>"305 Use Proxy"),
array(380=>"380 Alternative Service"),
array(400=>"400 Bad Request"),
array(401=>"401 Unauthorized"),
array(402=>"402 Payment Required (Reserved for future use)"),
array(403=>"403 Forbidden"),
array(404=>"404 Not Found"),
array(405=>"405 Method Not Allowed"),
array(406=>"406 Not Acceptable"),
array(407=>"407 Proxy Authentication Required"),
array(408=>"408 Request Timeout"),
array(409=>"409 Conflict"),
array(410=>"410 Gone"),
array(413=>"413 Request Entity Too Large"),
array(414=>"414 Request-URI Too Long"),
array(415=>"415 Unsupported Media Type"),
array(416=>"416 Unsupported URI Scheme"),
array(420=>"420 Bad Extension"),
array(421=>"421 Extension Required"),
array(422=>"422 Session Interval Too Small"),
array(423=>"423 Interval Too Brief"),
array(480=>"480 Temporarily Unavailable"),
array(481=>"481 Call/Transaction Does Not Exist"),
array(482=>"482 Loop Detected"),
array(483=>"483 Too Many Hops"),
array(484=>"484 Address Incomplete"),
array(485=>"485 Ambiguous"),
array(486=>"486 Busy Here"),
array(487=>"487 Request Terminated"),
array(488=>"488 Not Acceptable Here"),
array(491=>"491 Request Pending"),
array(493=>"493 Undecipherable"),
array(500=>"500 Server Internal Error"),
array(501=>"501 Not Implemented"),
array(502=>"502 Bad Gateway"),
array(503=>"503 Service Unavailable"),
array(504=>"504 Server Time-out"),
array(505=>"505 Version Not Supported"),
array(513=>"513 Message Too Large"),
array(600=>"600 Busy Everywhere"),
array(603=>"603 Decline"),
array(604=>"604 Does Not Exist Anywhere"),
array(606=>"606 Not Acceptable")
);

$isgw_cause=array(array(901=>"901 means no channel processing resources are left to establish a call"),
array(902=>"902 means no isdn channels are free to establish a call"),
array(903=>"903 means no general resources are free to establish a call"),
array(904=>"904 means no match in isgw dialplan was found"),
array(905=>"905 means the outgoing ISDN Number would contain non-digit characters"),
array(906=>"906 means no ISDN channels are free (ports are down)"),
array(907=>"907 means no ANALOG ports are free"),
array(908=>"908 means no ANALOG channels are free (ports are down)"),
array(909=>"909 means a failover timeout occurred"),
array(910=>"910 means no GSM ports are free"),
array(911=>"911 means no free dialplan entry was found"),
array(912=>"912 means ISDN timeout occurred"),
array(913=>"913 means not enough SIP licenses"),
array(914=>"914 means no CAS ports are free"),
array(915=>"915 means Call blocked by authentication server"),
array(916=>"916 means RTP offer not acceptable"),
array(917=>"917 means T38 offer not acceptable"),
array(918=>"918 means Call limit exceeded"),
array(9000=>"9000 means SIP T0 timeout occurred"),
array(9180=>"9180 means SIP T180 timeout occurred"),
array(9183=>"9183 means SIP T183 timeout occurred"),
array(9200=>"9200 means SIP T200 timeout occurred"),

);

$analog_causes=array(array(17=>"17: User busy"),
array(21=>"21: Call rejected"));
?>
